@@ -31,6 +31,7 @@ from debputy.commands.debputy_cmd.context import (
     CommandArg,
 )
 from debputy.commands.debputy_cmd.output import _stream_to_pager, _output_styling
+from debputy.commands.debputy_cmd.plugin_cmds import lookup_pmr_rule
 from debputy.dh_migration.migrators import MIGRATORS
 from debputy.exceptions import (
     DebputyRuntimeError,
@@ -41,6 +42,7 @@ from debputy.exceptions import (
     SymlinkLoopError,
 )
 from debputy.highlevel_manifest import HighLevelManifest
+from debputy.manifest_parser.parser_doc import render_rule
 from debputy.package_build.assemble_deb import (
     assemble_debs,
 )
@@ -99,6 +101,7 @@ from debputy.util import (
     integrated_with_debhelper,
     PRINT_BUILD_SYSTEM_COMMAND,
     PRINT_COMMAND,
+    manifest_format_doc,
 )
 
 
@@ -661,6 +664,64 @@ def _run_tests_for_plugin(context: CommandContext) -> None:
     _run_tests(context, tests, cwd="/")
 
 
+@internal_commands.register_subcommand(
+    "process-template",
+    help_description="[Internal command] Process a debputy template",
+    requested_plugins_only=True,
+    argparser=[
+        add_arg(
+            "template_file",
+            metavar="template-file",
+            help="The source template to be processed.",
+        ),
+        add_arg(
+            "output_file",
+            metavar="output-file",
+            help="Where to place the resulting file should be written",
+        ),
+    ],
+)
+def _process_template(context: CommandContext) -> None:
+    parsed_args = context.parsed_args
+    template_file = parsed_args.template_file
+    output_file = parsed_args.output_file
+
+    try:
+        from jinja2 import Environment, FileSystemLoader, Template
+    except ImportError:
+        _error("This sub-command requires a compatible version of python3-jinja2")
+
+    feature_set = context.load_plugins()
+
+    with open(template_file) as fd:
+        jinja_template = Template(
+            fd.read(),
+            autoescape=False,
+            block_start_string="<%",
+            block_end_string="%>",
+            variable_start_string="<<",
+            variable_end_string=">>",
+            comment_start_string="<#",
+            comment_end_string="#>",
+        )
+
+    def _render_pmr(rule_name: str, heading: str) -> str:
+        pmr_rule = lookup_pmr_rule(feature_set, rule_name)
+        return render_rule(
+            pmr_rule.rule_name,
+            pmr_rule.parser,
+            pmr_rule.plugin_metadata,
+            is_root_rule=pmr_rule.is_root_rule,
+            heading=heading,
+            include_ref_doc_link=False,
+            include_alt_format=False,
+            manifest_format_url="",
+        )
+
+    with open(output_file, "w") as fd:
+        fd.write(jinja_template.render(render_pmr=_render_pmr))
+
+
 @internal_commands.register_subcommand(
     "dpkg-build-driver-run-task",
     help_description="[Internal command] Perform a given Dpkg::BuildDriver task (Not stable API)",
