@@ -1,4 +1,5 @@
 import argparse
+import dataclasses
 import operator
 import os
 import sys
@@ -15,7 +16,6 @@ from typing import (
     Callable,
 )
 
-from debputy import DEBPUTY_DOC_ROOT_DIR
 from debputy.analysis.analysis_util import flatten_ppfs
 from debputy.commands.debputy_cmd.context import (
     CommandContext,
@@ -29,18 +29,19 @@ from debputy.commands.debputy_cmd.output import (
 )
 from debputy.exceptions import DebputySubstitutionError
 from debputy.filesystem_scan import build_virtual_fs
-from debputy.manifest_parser.tagging_types import TypeMapping
 from debputy.manifest_parser.declarative_parser import (
     BASIC_SIMPLE_TYPES,
 )
 from debputy.manifest_parser.parser_data import ParserContextData
 from debputy.manifest_parser.parser_doc import render_rule
+from debputy.manifest_parser.tagging_types import TypeMapping
 from debputy.manifest_parser.util import unpack_type, AttributePath
 from debputy.packager_provided_files import detect_all_packager_provided_files
 from debputy.plugin.api.example_processing import (
     process_discard_rule_example,
     DiscardVerdict,
 )
+from debputy.plugin.api.feature_set import PluginProvidedFeatureSet
 from debputy.plugin.api.impl import plugin_metadata_for_debputys_own_plugin
 from debputy.plugin.api.impl_types import (
     PackagerProvidedFileClassSpec,
@@ -50,6 +51,8 @@ from debputy.plugin.api.impl_types import (
     AutomaticDiscardRuleExample,
     MetadataOrMaintscriptDetector,
     PluginProvidedTypeMapping,
+    DebputyPluginMetadata,
+    DeclarativeInputParser,
 )
 from debputy.plugin.api.parser_tables import (
     SUPPORTED_DISPATCHABLE_TABLE_PARSERS,
@@ -59,7 +62,7 @@ from debputy.plugin.api.spec import (
     TypeMappingExample,
 )
 from debputy.substitution import Substitution
-from debputy.util import _error, _warn
+from debputy.util import _error, _warn, manifest_format_doc
 
 plugin_dispatcher = ROOT_COMMAND.add_dispatching_subcommand(
     "plugin",
@@ -623,7 +626,7 @@ def _determine_ppf(
 
     if ppf_name in ("debian/control", "debian/debputy.manifest", "debian/rules"):
         if ppf_name == "debian/debputy.manifest":
-            doc = f"{DEBPUTY_DOC_ROOT_DIR}/MANIFEST-FORMAT.md"
+            doc = manifest_format_doc("")
         else:
             doc = "Debian Policy Manual or a packaging tutorial"
         _error(
@@ -766,20 +769,26 @@ def _plugin_cmd_show_ppf(context: CommandContext) -> None:
         )
 
 
-@plugin_show_cmds.register_subcommand(
-    ["pluggable-manifest-rules", "p-m-r", "pmr"],
-    help_description="Pluggable manifest rules (such as install rules)",
-    argparser=add_arg(
-        "pmr_rule_name",
-        metavar="rule-name",
-        help="Name of the rule (such as `install`) to display details about",
-    ),
-)
-def _plugin_cmd_show_manifest_rule(context: CommandContext) -> None:
-    feature_set = context.load_plugins()
-    parsed_args = context.parsed_args
+class UnresolvableRuleError(ValueError):
+    pass
+
+
+@dataclasses.dataclass
+class PMRRuleLookup:
+    rule_name: str
+    parser: DeclarativeInputParser
+    parser_type_name: str
+    plugin_metadata: DebputyPluginMetadata
+    is_root_rule: bool
+    manifest_attribute_path: str
+
+
+def lookup_pmr_rule(
+    feature_set: PluginProvidedFeatureSet,
+    pmr_rule_name: str,
+) -> PMRRuleLookup:
     req_rule_type = None
-    rule_name = parsed_args.pmr_rule_name
+    rule_name = pmr_rule_name
     if "::" in rule_name and rule_name != "::":
         req_rule_type, rule_name = rule_name.split("::", 1)
 
@@ -805,13 +814,13 @@ def _plugin_cmd_show_manifest_rule(context: CommandContext) -> None:
 
     if len(matched) != 1 and (matched or rule_name != "::"):
         if not matched:
-            _error(
-                f"Could not find any pluggable manifest rule related to {parsed_args.pmr_rule_name}."
+            raise UnresolvableRuleError(
+                f"Could not find any pluggable manifest rule related to {pmr_rule_name}."
                 f" Please use `debputy plugin list pluggable-manifest-rules` to see the list of rules."
             )
         match_a = matched[0][0]
         match_b = matched[1][0]
-        _error(
+        raise UnresolvableRuleError(
             f"The name {rule_name} was ambiguous and matched multiple rule types.  Please use"
             f" <rule-type>::{rule_name} to clarify which rule to use"
             f" (such as {_parser_type_name(match_a)}::{rule_name} or {_parser_type_name(match_b)}::{rule_name})."
@@ -836,23 +845,52 @@ def _plugin_cmd_show_manifest_rule(context: CommandContext) -> None:
         manifest_attribute_path = ""
 
     is_root_rule = rule_name == "::"
+    return PMRRuleLookup(
+        rule_name,
+        parser,
+        parser_type_name,
+        plugin_metadata,
+        is_root_rule,
+        manifest_attribute_path,
+    )
+
+
+@plugin_show_cmds.register_subcommand(
+    ["pluggable-manifest-rules", "p-m-r", "pmr"],
+    help_description="Pluggable manifest rules (such as install rules)",
+    argparser=add_arg(
+        "pmr_rule_name",
+        metavar="rule-name",
+        help="Name of the rule (such as `install`) to display details about",
+    ),
+)
+def _plugin_cmd_show_manifest_rule(context: CommandContext) -> None:
+    feature_set = context.load_plugins()
+    parsed_args = context.parsed_args
+
+    try:
+        pmr_rule = lookup_pmr_rule(feature_set, parsed_args.pmr_rule_name)
+    except UnresolvableRuleError as e:
+        _error(e.args[0])
+
     print(
         render_rule(
-            rule_name,
-            parser,
-            plugin_metadata,
-            is_root_rule=is_root_rule,
+            pmr_rule.rule_name,
+            pmr_rule.parser,
+            pmr_rule.plugin_metadata,
+            is_root_rule=pmr_rule.is_root_rule,
         )
     )
 
-    if not is_root_rule:
+    if not pmr_rule.is_root_rule:
+        manifest_attribute_path = pmr_rule.manifest_attribute_path
         print(
             f"Used in: {manifest_attribute_path if manifest_attribute_path != '<ROOT>' else 'The manifest root'}"
         )
-        print(f"Rule reference: {parser_type_name}::{rule_name}")
-        print(f"Plugin: {plugin_metadata.plugin_name}")
+        print(f"Rule reference: {pmr_rule.parser_type_name}::{pmr_rule.rule_name}")
+        print(f"Plugin: {pmr_rule.plugin_metadata.plugin_name}")
     else:
-        print(f"Rule reference: {rule_name}")
+        print(f"Rule reference: {pmr_rule.rule_name}")
 
     print()
     print(
