@@ -30,6 +30,8 @@ from typing import (
     Any,
     Union,
     Mapping,
+    AbstractSet,
+    TYPE_CHECKING,
 )
 
 import debian.deb822
@@ -40,16 +42,10 @@ from debputy._deb_options_profiles import DebBuildOptionsAndProfiles
 from debputy.architecture_support import DpkgArchitectureBuildProcessValuesTable
 from debputy.dh.debhelper_emulation import (
     dhe_install_pkg_file_as_ctrl_file_if_present,
-    dhe_dbgsym_root_dir,
 )
 from debputy.elf_util import find_all_elf_files, ELF_MAGIC
 from debputy.exceptions import DebputyDpkgGensymbolsError
 from debputy.filesystem_scan import FSPath, FSROOverlay
-from debputy.highlevel_manifest import (
-    HighLevelManifest,
-    PackageTransformationDefinition,
-    BinaryPackageData,
-)
 from debputy.maintscript_snippet import (
     ALL_CONTROL_SCRIPTS,
     MaintscriptSnippetContainer,
@@ -93,6 +89,14 @@ from debputy.util import (
     _warn,
 )
 
+if TYPE_CHECKING:
+    from debputy.highlevel_manifest import (
+        HighLevelManifest,
+        PackageTransformationDefinition,
+        BinaryPackageData,
+    )
+
+
 VP = TypeVar("VP", bound=VirtualPath, covariant=True)
 
 _T64_REGEX = re.compile("^lib.*t64(?:-nss)?$")
@@ -826,7 +830,7 @@ def relocate_dwarves_into_dbgsym_packages(
 
 
 def run_package_processors(
-    manifest: HighLevelManifest,
+    manifest: "HighLevelManifest",
     package_metadata_context: PackageProcessingContext,
     fs_root: VirtualPath,
 ) -> None:
@@ -840,7 +844,7 @@ def run_package_processors(
 
 def cross_package_control_files(
     package_data_table: PackageDataTable,
-    manifest: HighLevelManifest,
+    manifest: "HighLevelManifest",
 ) -> None:
     errors = []
     combined_shlibs = ShlibsContent()
@@ -964,8 +968,8 @@ def _relevant_service_definitions(
 
 
 def handle_service_management(
-    binary_package_data: BinaryPackageData,
-    manifest: HighLevelManifest,
+    binary_package_data: "BinaryPackageData",
+    manifest: "HighLevelManifest",
     package_metadata_context: PackageProcessingContext,
     fs_root: VirtualPath,
     feature_set: PluginProvidedFeatureSet,
@@ -1081,8 +1085,8 @@ def handle_service_management(
 
 
 def setup_control_files(
-    binary_package_data: BinaryPackageData,
-    manifest: HighLevelManifest,
+    binary_package_data: "BinaryPackageData",
+    manifest: "HighLevelManifest",
     dbgsym_fs_root: VirtualPath,
     dbgsym_ids: List[str],
     package_metadata_context: PackageProcessingContext,
@@ -1208,8 +1212,7 @@ def setup_control_files(
 
     if binary_package.is_udeb:
         _generate_control_files(
-            binary_package_data.source_package,
-            binary_package,
+            binary_package_data,
             package_state,
             control_output_dir,
             fs_root,
@@ -1245,8 +1248,7 @@ def setup_control_files(
         )
 
     _generate_control_files(
-        binary_package_data.source_package,
-        binary_package,
+        binary_package_data,
         package_state,
         control_output_dir,
         fs_root,
@@ -1324,7 +1326,7 @@ def _compute_installed_size(fs_root: VirtualPath) -> int:
 def _generate_dbgsym_control_file_if_relevant(
     binary_package: BinaryPackage,
     dbgsym_fs_root: VirtualPath,
-    dbgsym_root_dir: str,
+    dbgsym_control_dir: str,
     dbgsym_ids: str,
     multi_arch: Optional[str],
     dctrl: str,
@@ -1341,7 +1343,6 @@ def _generate_dbgsym_control_file_if_relevant(
         extra_params.append(f"-DMulti-Arch={multi_arch}")
     extra_params.append("-UReplaces")
     extra_params.append("-UBreaks")
-    dbgsym_control_dir = os.path.join(dbgsym_root_dir, "DEBIAN")
     ensure_dir(dbgsym_control_dir)
     # Pass it via cmd-line to make it more visible that we are providing the
     # value.  It also prevents the dbgsym package from picking up this value.
@@ -1365,7 +1366,9 @@ def _generate_dbgsym_control_file_if_relevant(
         "-ldebian/changelog",
         "-T/dev/null",
         f"-c{dctrl}",
-        f"-P{dbgsym_root_dir}",
+        f"-O{dbgsym_control_dir}/control",
+        # Use a placeholder for -P to ensure failure if we forgot to override a path parameter
+        "-P/non-existent",
         f"-DPackage={package}-dbgsym",
         "-DDepends=" + package + " (= ${binary:Version})",
         f"-DDescription=debug symbols for {package}",
@@ -1395,7 +1398,7 @@ def _generate_dbgsym_control_file_if_relevant(
             f"Attempting to generate DEBIAN/control file for {package}-dbgsym failed. Please review the output from "
             " dpkg-gencontrol above to understand what went wrong."
         )
-    os.chmod(os.path.join(dbgsym_root_dir, "DEBIAN", "control"), 0o644)
+    os.chmod(os.path.join(dbgsym_control_dir, "control"), 0o644)
 
 
 def _all_parent_directories_of(directories: Iterable[str]) -> Set[str]:
@@ -1408,14 +1411,55 @@ def _all_parent_directories_of(directories: Iterable[str]) -> Set[str]:
     return result
 
 
+def _compute_multi_arch_for_arch_all_doc(
+    binary_package: BinaryPackage,
+    fs_root: FSPath,
+) -> Optional[str]:
+    if not binary_package.name.endswith(("-doc", "-docs")):
+        # We limit by package name, since there are tricks involving a `Multi-Arch: no` depending on a
+        # `Multi-Arch: same` to emulate `Multi-Arch: allowed`. Said `Multi-Arch: no` can have no contents.
+        #
+        # That case seems unrealistic for -doc/-docs packages and accordingly the limitation here.
+        return None
+    acceptable_no_descend_paths = {
+        "./usr/share/doc",
+    }
+    acceptable_files = {f"./usr/share/lintian/overrides/{binary_package.name}"}
+    if _any_unacceptable_paths(
+        fs_root,
+        acceptable_no_descend_paths=acceptable_no_descend_paths,
+        acceptable_files=acceptable_files,
+    ):
+        return None
+    return "foreign"
+
+
+def _any_unacceptable_paths(
+    fs_root: FSPath,
+    *,
+    acceptable_no_descend_paths: Union[List[str], AbstractSet[str]] = frozenset(),
+    acceptable_files: Union[List[str], AbstractSet[str]] = frozenset(),
+) -> bool:
+    acceptable_intermediate_dirs = _all_parent_directories_of(
+        itertools.chain(acceptable_no_descend_paths, acceptable_files)
+    )
+    for fs_path, children in fs_root.walk():
+        path = fs_path.path
+        if path in acceptable_no_descend_paths:
+            children.clear()
+            continue
+        if path in acceptable_intermediate_dirs or path in acceptable_files:
+            continue
+        return True
+    return False
+
+
 def _auto_compute_multi_arch(
     binary_package: BinaryPackage,
     control_output_dir: str,
     fs_root: FSPath,
 ) -> Optional[str]:
     resolved_arch = binary_package.resolved_architecture
-    if resolved_arch == "all":
-        return None
     if any(
         script
         for script in ALL_CONTROL_SCRIPTS
@@ -1423,6 +1467,9 @@ def _auto_compute_multi_arch(
     ):
         return None
 
+    if resolved_arch == "all":
+        return _compute_multi_arch_for_arch_all_doc(binary_package, fs_root)
+
     resolved_multiarch = binary_package.deb_multiarch
     assert resolved_arch != "all"
     acceptable_no_descend_paths = {
@@ -1442,17 +1489,17 @@ def _auto_compute_multi_arch(
             "README.Debian.gz",
         )
     }
-    acceptable_intermediate_dirs = _all_parent_directories_of(
-        itertools.chain(acceptable_no_descend_paths, acceptable_files)
-    )
 
-    for fs_path, children in fs_root.walk():
-        path = fs_path.path
-        if path in acceptable_no_descend_paths:
-            children.clear()
-            continue
-        if path in acceptable_intermediate_dirs or path in acceptable_files:
-            continue
+    # Note that the lintian-overrides file is deliberately omitted from the allow-list. We would have to know that the
+    # override does not use architecture segments. With pure debputy, this is guaranteed (debputy
+    # does not allow lintian-overrides with architecture segment). However, with a mixed debhelper + debputy,
+    # `dh_lintian` allows it with compat 13 or older.
+
+    if _any_unacceptable_paths(
+        fs_root,
+        acceptable_no_descend_paths=acceptable_no_descend_paths,
+        acceptable_files=acceptable_files,
+    ):
         return None
 
     return "same"
@@ -1603,16 +1650,17 @@ def _handle_relationship_substvars(
 
 
 def _generate_control_files(
-    source_package: SourcePackage,
-    binary_package: BinaryPackage,
-    package_state: PackageTransformationDefinition,
+    binary_package_data: "BinaryPackageData",
+    package_state: "PackageTransformationDefinition",
     control_output_dir: str,
     fs_root: FSPath,
     substvars: FlushableSubstvars,
     dbgsym_root_fs: Optional[VirtualPath],
     dbgsym_build_ids: Optional[List[str]],
 ) -> None:
-    package = binary_package.name
+    binary_package = binary_package_data.binary_package
+    source_package = binary_package_data.source_package
+    package_name = binary_package.name
     extra_common_params = []
     extra_params_specific = []
     _ensure_base_substvars_defined(substvars)
@@ -1641,7 +1689,6 @@ def _generate_control_files(
     elif ma_value == "no":
         extra_common_params.append("-UMulti-Arch")
 
-    dbgsym_root_dir = dhe_dbgsym_root_dir(binary_package)
     dbgsym_ids = " ".join(dbgsym_build_ids) if dbgsym_build_ids else ""
     if package_state.binary_version is not None:
         extra_common_params.append(f"-v{package_state.binary_version}")
@@ -1663,17 +1710,18 @@ def _generate_control_files(
 
         if has_dbgsym:
             assert dbgsym_root_fs is not None  # mypy hint
+            dbgsym_ctrl_dir = binary_package_data.dbgsym_info.dbgsym_ctrl_dir
             _generate_dbgsym_control_file_if_relevant(
                 binary_package,
                 dbgsym_root_fs,
-                dbgsym_root_dir,
+                dbgsym_ctrl_dir,
                 dbgsym_ids,
                 ma_value,
                 dctrl_file,
                 extra_common_params,
             )
             generate_md5sums_file(
-                os.path.join(dbgsym_root_dir, "DEBIAN"),
+                dbgsym_ctrl_dir,
                 dbgsym_root_fs,
             )
         elif dbgsym_ids:
@@ -1682,13 +1730,14 @@ def _generate_control_files(
         ctrl_file = os.path.join(control_output_dir, "control")
         dpkg_cmd = [
             "dpkg-gencontrol",
-            f"-p{package}",
+            f"-p{package_name}",
             # FIXME: Support d/<pkg>.changelog at some point.
             "-ldebian/changelog",
             f"-c{dctrl_file}",
             f"-T{flushed_substvars}",
             f"-O{ctrl_file}",
-            f"-P{control_output_dir}",
+            # Use a placeholder for -P to ensure failure if we forgot to override a path parameter
+            "-P/non-existent",
             *extra_common_params,
             *extra_params_specific,
         ]
@@ -1697,7 +1746,7 @@ def _generate_control_files(
             subprocess.check_call(dpkg_cmd)
         except subprocess.CalledProcessError:
             _error(
-                f"Attempting to generate DEBIAN/control file for {package} failed. Please review the output from "
+                f"Attempting to generate DEBIAN/control file for {package_name} failed. Please review the output from "
                 " dpkg-gencontrol above to understand what went wrong."
             )
         os.chmod(ctrl_file, 0o644)
