@@ -2,6 +2,7 @@ import dataclasses
 import functools
 import os
 import textwrap
+from collections import defaultdict
 from contextlib import suppress
 from dataclasses import dataclass, field
 from typing import (
@@ -22,15 +23,16 @@ from typing import (
 )
 
 from debian.debian_support import DpkgArchTable
-from ._deb_options_profiles import DebBuildOptionsAndProfiles
-from ._manifest_constants import *
-from .architecture_support import DpkgArchitectureBuildProcessValuesTable
-from .builtin_manifest_rules import builtin_mode_normalization_rules
+
 from debputy.dh.debhelper_emulation import (
     dhe_dbgsym_root_dir,
     assert_no_dbgsym_migration,
     read_dbgsym_file,
 )
+from ._deb_options_profiles import DebBuildOptionsAndProfiles
+from ._manifest_constants import *
+from .architecture_support import DpkgArchitectureBuildProcessValuesTable
+from .builtin_manifest_rules import builtin_mode_normalization_rules
 from .exceptions import DebputySubstitutionError
 from .filesystem_scan import FSPath, FSRootDir, FSROOverlay
 from .installations import (
@@ -63,7 +65,13 @@ from .plugin.api.impl_types import (
     PackageProcessingContextProvider,
     PackageDataTable,
 )
-from .plugin.api.spec import FlushableSubstvars, VirtualPath
+from .plugin.api.spec import (
+    FlushableSubstvars,
+    VirtualPath,
+    DebputyIntegrationMode,
+    INTEGRATION_MODE_DH_DEBPUTY_RRR,
+    INTEGRATION_MODE_FULL,
+)
 from .plugin.debputy.binary_package_rules import ServiceRule
 from .plugin.debputy.to_be_api_types import BuildRule
 from .plugin.plugin_state import run_in_context_of_plugin
@@ -86,22 +94,45 @@ from .yaml.compat import CommentedMap, CommentedSeq
 
 @dataclass(slots=True)
 class DbgsymInfo:
+    binary_package: BinaryPackage
     dbgsym_fs_root: FSPath
+    _dbgsym_root_fs: Optional[str]
     dbgsym_ids: List[str]
 
+    @property
+    def dbgsym_root_dir(self) -> str:
+        root_dir = self._dbgsym_root_fs
+        if root_dir is None:
+            root_dir = generated_content_dir(
+                package=self.binary_package,
+                subdir_key="dbgsym-fs-root",
+            )
+            self._dbgsym_root_fs = root_dir
+        return root_dir
+
+    @property
+    def dbgsym_ctrl_dir(self) -> str:
+        return os.path.join(self.dbgsym_root_dir, "DEBIAN")
+
 
 @dataclass(slots=True, frozen=True)
 class BinaryPackageData:
     source_package: SourcePackage
     binary_package: BinaryPackage
     binary_staging_root_dir: str
-    control_output_dir: Optional[str]
     fs_root: FSPath
     substvars: FlushableSubstvars
     package_metadata_context: PackageProcessingContextProvider
     ctrl_creator: BinaryCtrlAccessorProviderCreator
     dbgsym_info: DbgsymInfo
 
+    @property
+    def control_output_dir(self) -> str:
+        return generated_content_dir(
+            package=self.binary_package,
+            subdir_key="DEBIAN",
+        )
+
 
 @dataclass(slots=True)
 class PackageTransformationDefinition:
@@ -1185,12 +1216,15 @@ class HighLevelManifest:
 
     def perform_installations(
         self,
+        integration_mode: DebputyIntegrationMode,
         *,
         install_request_context: Optional[InstallSearchDirContext] = None,
-        enable_manifest_installation_feature: bool = True,
     ) -> PackageDataTable:
         package_data_dict = {}
         package_data_table = PackageDataTable(package_data_dict)
+        enable_manifest_installation_feature = (
+            integration_mode != INTEGRATION_MODE_DH_DEBPUTY_RRR
+        )
         if install_request_context is None:
 
             @functools.lru_cache(None)
@@ -1200,12 +1234,58 @@ class HighLevelManifest:
             dtmp_dir = _as_path("debian/tmp")
             source_root_dir = _as_path(".")
             into = frozenset(self._binary_packages.values())
-            default_search_dirs = [dtmp_dir]
             per_package_search_dirs = {
                 t.binary_package: [_as_path(f.match_rule.path) for f in t.search_dirs]
                 for t in self.package_transformations.values()
                 if t.search_dirs is not None
             }
+
+            if integration_mode == INTEGRATION_MODE_FULL:
+                # In this mode, we have no default search dir. Everything ends up being
+                # per-package instead (since that is easier logic-wise).
+                #
+                # Even dtmp_dir is omitted here (since it is not universally applicable).
+                # Note we still initialize dtmp_dir, since it affects a later guard.
+                default_search_dirs = []
+                seen_pp_search_dirs: Set[Tuple[BinaryPackage, str]] = set()
+                # TODO: We should **not** re-detect the default build system here. Instead,
+                #  we should have accumulated these per-package install dirs when we
+                #  invoked the build systems (notably, we are also not using the right
+                #  environment, which happens to work for now but that might break in
+                #  the future).
+                build_rules = self.build_rules
+                if build_rules is None:
+                    from .build_support.buildsystem_detection import (
+                        auto_detect_buildsystem,
+                    )
+
+                    bs = auto_detect_buildsystem(self)
+                    build_rules = [bs] if bs is not None else []
+
+                for build_rule in build_rules:
+                    dest_dir = build_rule.install_dest_dir()
+                    if dest_dir is None:
+                        continue
+                    dest_path = _as_path(dest_dir)
+                    for pkg in build_rule.for_packages:
+                        seen_key = (pkg, dest_dir)
+                        if seen_key in seen_pp_search_dirs:
+                            continue
+                        seen_pp_search_dirs.add(seen_key)
+                        if pkg not in per_package_search_dirs:
+                            per_package_search_dirs[pkg] = [dest_path]
+                        else:
+                            per_package_search_dirs[pkg].append(dest_path)
+
+                # We can end here with per_package_search_dirs having no search dirs for any package
+                # (single binary, where everything is installed into d/<pkg> is the most common case).
+                #
+                # This is not a problem in itself as the installation rules can still apply to the
+                # source root and there should be no reason to install something from d/<pkg> into
+                # d/<another-pkg>
+            else:
+                default_search_dirs = [dtmp_dir]
+
             search_dirs = _determine_search_dir_order(
                 per_package_search_dirs,
                 into,
@@ -1252,6 +1332,7 @@ class HighLevelManifest:
         if (
             enable_manifest_installation_feature
             and self._install_rules is None
+            # TODO: Should we also do this for full mode when build systems provided search dirs?
             and dtmp_dir is not None
             and os.path.isdir(dtmp_dir.fs_path)
         ):
@@ -1360,12 +1441,8 @@ class HighLevelManifest:
                 )
                 # We do not want to touch the substvars file (non-clean rebuild contamination)
                 substvars.substvars_path = None
-                control_output_dir = generated_content_dir(
-                    package=dctrl_bin, subdir_key="DEBIAN"
-                )
             else:
                 substvars = FlushableSubstvars()
-                control_output_dir = None
 
             udeb_package = self._binary_packages.get(f"{package}-udeb")
             if udeb_package and not udeb_package.is_udeb:
@@ -1388,8 +1465,10 @@ class HighLevelManifest:
 
             if not enable_manifest_installation_feature:
                 assert_no_dbgsym_migration(dctrl_bin)
-                dh_dbgsym_root_fs = FSROOverlay.create_root_dir(
-                    "", dhe_dbgsym_root_dir(dctrl_bin)
+                dh_dbgsym_root_fs = dhe_dbgsym_root_dir(dctrl_bin)
+                dh_dbgsym_root_path = FSROOverlay.create_root_dir(
+                    "",
+                    dh_dbgsym_root_fs,
                 )
                 dbgsym_root_fs = FSRootDir()
                 _install_everything_from_source_dir_if_present(
@@ -1398,17 +1477,21 @@ class HighLevelManifest:
                     path_matcher,
                     install_rule_context,
                     source_condition_context,
-                    dh_dbgsym_root_fs,
+                    dh_dbgsym_root_path,
                     into_dir=dbgsym_root_fs,
                 )
                 dbgsym_build_ids = read_dbgsym_file(dctrl_bin)
                 dbgsym_info = DbgsymInfo(
+                    dctrl_bin,
                     dbgsym_root_fs,
+                    os.path.join(dh_dbgsym_root_fs, "DEBIAN"),
                     dbgsym_build_ids,
                 )
             else:
                 dbgsym_info = DbgsymInfo(
+                    dctrl_bin,
                     FSRootDir(),
+                    None,
                     [],
                 )
 
@@ -1416,7 +1499,6 @@ class HighLevelManifest:
                 self._source_package,
                 dctrl_bin,
                 build_system_pkg_staging_dir,
-                control_output_dir,
                 fs_root,
                 substvars,
                 package_metadata_context,
