@@ -22,7 +22,7 @@ from typing import (
 )
 
 from debputy.exceptions import DebputyRuntimeError
-from debputy.filesystem_scan import FSPath
+from debputy.filesystem_scan import FSPath, FSRootDir
 from debputy.manifest_conditions import (
     ConditionContext,
     ManifestCondition,
@@ -702,7 +702,25 @@ class InstallRule(DebputyDispatchableType):
             and not self._condition.evaluate(condition_context)
         ) or not any(p.should_be_acted_on for p in into):
             # Rule is disabled; skip all its actions - also allow empty matches
-            # for this particular case.
+            # for this particular case. Though, we do go through the match and
+            # ensure all paths are reserved correctly such that the behavior
+            # between `binary-arch` vs `binary-indep` vs `binary` is consistent
+            root = FSRootDir()
+            for match in matches:
+                path = match.path
+                path_matcher.reserve(
+                    path,
+                    into,
+                    self._definition_source,
+                    is_exact_match=False,
+                )
+                if path.is_dir:
+                    self._install_dir_recursively(
+                        path_matcher,
+                        [root],
+                        match,
+                        into,
+                    )
             return
 
         if not matches:
@@ -757,7 +775,10 @@ class InstallRule(DebputyDispatchableType):
                         )
             if install_recursively_into_dirs:
                 self._install_dir_recursively(
-                    path_matcher, install_recursively_into_dirs, match, into
+                    path_matcher,
+                    install_recursively_into_dirs,
+                    match,
+                    into,
                 )
 
     def _install_dir_recursively(
@@ -1021,6 +1042,7 @@ class PPFInstallRule(InstallRule):
         "_into",
     )
 
+    # noinspection PyMissingConstructor
     def __init__(
         self,
         into: BinaryPackage,
@@ -1146,8 +1168,8 @@ class DiscardRule(InstallRule):
                 if s.search_dir.fs_path in matches
             )
             if len(limit_to) != len(search_dirs):
-                matches.difference(s.search_dir.fs_path for s in search_dirs)
-                paths = ":".join(matches)
+                m = matches.difference(s.search_dir.fs_path for s in search_dirs)
+                paths = ":".join(m)
                 _error(
                     f"The discard rule defined at {self._definition_source} mentions the following"
                     f" search directories that were not known to debputy: {paths}."
