@@ -245,20 +245,25 @@ def word_range_at_position(
     lines: List[str],
     line_no: int,
     char_offset: int,
-) -> types.Range:
+) -> TERange:
     line = lines[line_no]
     line_len = len(line)
     start_idx = char_offset
     end_idx = char_offset
-    while end_idx + 1 < line_len and not line[end_idx + 1].isspace():
-        end_idx += 1
 
-    while start_idx - 1 >= 0 and not line[start_idx - 1].isspace():
-        start_idx -= 1
+    for i in range(end_idx, line_len):
+        end_idx = i
+        if line[i].isspace():
+            break
 
-    return types.Range(
-        types.Position(line_no, start_idx),
-        types.Position(line_no, end_idx),
+    for i in range(start_idx, -1, -1):
+        if i > 0 and line[i].isspace():
+            break
+        start_idx = i
+
+    return TERange(
+        TEPosition(line_no, start_idx),
+        TEPosition(line_no, end_idx),
     )
 
 
