@@ -115,6 +115,8 @@ from debputy.plugin.api.spec import (
     reference_documentation,
     _DEBPUTY_DISPATCH_METADATA_ATTR_NAME,
     BuildSystemManifestRuleMetadata,
+    INTEGRATION_MODE_FULL,
+    only_integrations,
 )
 from debputy.plugin.api.std_docs import _STD_ATTR_DOCS
 from debputy.plugin.debputy.to_be_api_types import (
@@ -960,6 +962,8 @@ class DebputyPluginInitializerProvider(DebputyPluginInitializer):
             # pluggable_manifest_rule does the wrapping
             metadata.unwrapped_constructor,
             source_format=metadata.source_format,
+            inline_reference_documentation=metadata.online_reference_documentation,
+            expected_debputy_integration_mode=only_integrations(INTEGRATION_MODE_FULL),
         )
         self._auto_detectable_build_system(
             manifest_keyword,
