@@ -18,11 +18,11 @@ from typing import (
 from debputy import DEBPUTY_DOC_ROOT_DIR
 from debputy.maintscript_snippet import DpkgMaintscriptHelperCommand, MaintscriptSnippet
 from debputy.manifest_parser.base_types import FileSystemExactMatchRule
-from debputy.manifest_parser.tagging_types import DebputyParsedContent
-from debputy.manifest_parser.parse_hints import DebputyParseHint
 from debputy.manifest_parser.declarative_parser import ParserGenerator
 from debputy.manifest_parser.exceptions import ManifestParseException
+from debputy.manifest_parser.parse_hints import DebputyParseHint
 from debputy.manifest_parser.parser_data import ParserContextData
+from debputy.manifest_parser.tagging_types import DebputyParsedContent
 from debputy.manifest_parser.util import AttributePath
 from debputy.path_matcher import MatchRule, MATCH_ANYTHING, ExactFileSystemPath
 from debputy.plugin.api import reference_documentation
@@ -40,7 +40,7 @@ from debputy.plugin.api.spec import (
     not_integrations,
 )
 from debputy.transformation_rules import TransformationRule
-from debputy.util import _error
+from debputy.util import _error, manifest_format_doc
 
 ACCEPTABLE_CLEAN_ON_REMOVAL_FOR_GLOBS_AND_EXACT_MATCHES = frozenset(
     [
@@ -78,6 +78,7 @@ def register_binary_package_rules(api: DebputyPluginInitializerProvider) -> None
         source_format=str,
         inline_reference_documentation=reference_documentation(
             title="Custom binary version (`binary-version`)",
+            # FIXME: A .format is run on this and breaks the `{{FOO}}` variables
             description=textwrap.dedent(
                 """\
                 In the *rare* case that you need a binary package to have a custom version, you can use
@@ -100,7 +101,9 @@ def register_binary_package_rules(api: DebputyPluginInitializerProvider) -> None
                 either.
             """
             ),
-            reference_documentation_url=f"{DEBPUTY_DOC_ROOT_DIR}/MANIFEST-FORMAT.md#custom-binary-version-binary-version",
+            reference_documentation_url=manifest_format_doc(
+                "custom-binary-version-binary-version"
+            ),
         ),
     )
 
@@ -111,6 +114,7 @@ def register_binary_package_rules(api: DebputyPluginInitializerProvider) -> None
         _unpack_list,
         inline_reference_documentation=reference_documentation(
             title="Transformations (`transformations`)",
+            # FIXME: Format bug
             description=textwrap.dedent(
                 """\
                 You can define a `transformations` under the package definition, which is a list a transformation
@@ -137,7 +141,9 @@ def register_binary_package_rules(api: DebputyPluginInitializerProvider) -> None
                    overlap or conflict.
             """
             ),
-            reference_documentation_url=f"{DEBPUTY_DOC_ROOT_DIR}/MANIFEST-FORMAT.md#transformations-transformations",
+            reference_documentation_url=manifest_format_doc(
+                "transformations-transformations"
+            ),
         ),
     )
 
@@ -180,12 +186,12 @@ def register_binary_package_rules(api: DebputyPluginInitializerProvider) -> None
                 documented_attr(
                     "service",
                     textwrap.dedent(
-                        f"""\
+                        """\
                         Name of the service to match. The name is usually the basename of the service file.
                         However, aliases can also be used for relevant system managers. When aliases **and**
                         multiple service managers are involved, then the rule will apply to all matches.
                         For details on aliases, please see
-                        {DEBPUTY_DOC_ROOT_DIR}/MANIFEST-FORMAT.md#service-managers-and-aliases.
+                        [Service managers and aliases](${MANIFEST_FORMAT_DOC}#service-managers-and-aliases).
 
                           - Note: For systemd, the `.service` suffix can be omitted from name, but other
                             suffixes such as `.timer` cannot.
@@ -220,7 +226,7 @@ def register_binary_package_rules(api: DebputyPluginInitializerProvider) -> None
                         service will be affected. This can be used to specify separate rules for the same
                         service under different service managers.
                         - When this attribute is explicitly given, then all the listed service managers must
-                          provide at least one service matching the definition. In contract, when it is omitted,
+                          provide at least one service matching the definition. In contrast, when it is omitted,
                           then all service manager integrations are consulted but as long as at least one
                           service is match from any service manager, the rule is accepted.
                     """
@@ -267,7 +273,9 @@ def register_binary_package_rules(api: DebputyPluginInitializerProvider) -> None
                     ),
                 ),
             ],
-            reference_documentation_url=f"{DEBPUTY_DOC_ROOT_DIR}/MANIFEST-FORMAT.md#service-management-services",
+            reference_documentation_url=manifest_format_doc(
+                "service-management-services"
+            ),
         ),
     )
 
@@ -334,7 +342,9 @@ def register_binary_package_rules(api: DebputyPluginInitializerProvider) -> None
         This feature resembles the concept of `rpm`'s `%ghost` files.
             """
             ),
-            reference_documentation_url=f"{DEBPUTY_DOC_ROOT_DIR}/MANIFEST-FORMAT.md#remove-runtime-created-paths-on-purge-or-post-removal-clean-after-removal",
+            reference_documentation_url=manifest_format_doc(
+                "remove-runtime-created-paths-on-purge-or-post-removal-clean-after-removal"
+            ),
         ),
     )
 
@@ -384,7 +394,9 @@ def register_binary_package_rules(api: DebputyPluginInitializerProvider) -> None
         exists and is a directory, it will also be checked for "not-installed" paths.
             """
             ),
-            reference_documentation_url=f"{DEBPUTY_DOC_ROOT_DIR}/MANIFEST-FORMAT.md#custom-installation-time-search-directories-installation-search-dirs",
+            reference_documentation_url=manifest_format_doc(
+                "custom-installation-time-search-directories-installation-search-dirs"
+            ),
         ),
     )
 
@@ -556,7 +568,9 @@ _CLEAN_AFTER_REMOVAL_RULE_PARSER = ParserGenerator().generate_parser(
     CleanAfterRemovalRule,
     source_content=Union[CleanAfterRemovalRuleSourceFormat, str, List[str]],
     inline_reference_documentation=reference_documentation(
-        reference_documentation_url=f"{DEBPUTY_DOC_ROOT_DIR}/MANIFEST-FORMAT.md#remove-runtime-created-paths-on-purge-or-post-removal-clean-after-removal",
+        reference_documentation_url=manifest_format_doc(
+            "remove-runtime-created-paths-on-purge-or-post-removal-clean-after-removal"
+        ),
     ),
 )
 
