@@ -32,6 +32,7 @@ from typing import (
 
 from debian.deb822 import Deb822
 
+from debputy import DEBPUTY_DOC_ROOT_DIR
 from debputy.architecture_support import DpkgArchitectureBuildProcessValuesTable
 from debputy.exceptions import DebputySubstitutionError
 
@@ -258,6 +259,11 @@ def _normalize_link_target(link_target: str) -> str:
     return "/".join(result)
 
 
+def manifest_format_doc(anchor: str) -> str:
+    manifest_format = f"{DEBPUTY_DOC_ROOT_DIR}/MANIFEST-FORMAT.md"
+    return f"{manifest_format}#{anchor}" if anchor else manifest_format
+
+
 def _backslash_escape(m: re.Match[str]) -> str:
     return "\\" + m.group(0)
 
@@ -325,6 +331,7 @@ def run_command(
     env: Optional[Mapping[str, str]] = None,
     env_mod: Optional["EnvironmentModification"] = None,
     print_at_log_level: int = PRINT_COMMAND,
+    raise_file_not_found_on_missing_command: bool = False,
 ) -> None:
     print_command(
         *args,
@@ -343,6 +350,13 @@ def run_command(
     # At least "clean_logic.py" relies on catching FileNotFoundError
     except KeyboardInterrupt:
         _error(f"Interrupted (SIGINT) while running {escape_shell(*args)}")
+    except FileNotFoundError:
+        if raise_file_not_found_on_missing_command:
+            raise
+        if "/" in args[0]:
+            _error(f"Could not run {escape_shell(args[0])}: Path does not exist")
+        # Use the `command not found` to aid existing log pattern
+        _error(f"{escape_shell(args[0])}: command not found")
     except subprocess.CalledProcessError as e:
         _error(f"The command {escape_shell(*args)} failed with status: {e.returncode}")
 
@@ -353,6 +367,7 @@ def run_build_system_command(
     env: Optional[Mapping[str, str]] = None,
     env_mod: Optional["EnvironmentModification"] = None,
     print_at_log_level: int = PRINT_BUILD_SYSTEM_COMMAND,
+    raise_file_not_found_on_missing_command: bool = False,
 ) -> None:
     run_command(
         *args,
@@ -360,6 +375,7 @@ def run_build_system_command(
         env=env,
         env_mod=env_mod,
         print_at_log_level=print_at_log_level,
+        raise_file_not_found_on_missing_command=raise_file_not_found_on_missing_command,
     )
 
 
